@@ -365,8 +365,7 @@ gjs_intern_string_to_id(JSContext  *cx,
 {
     JSAutoRequest ar(cx);
     JS::RootedString str(cx, JS_AtomizeAndPinString(cx, string));
-    JS::RootedId id(cx, INTERNED_STRING_TO_JSID(cx, str));
-    return id;
+    return INTERNED_STRING_TO_JSID(cx, str);
 }
 
 static std::string
