@@ -25,6 +25,7 @@
 #define __GJS_JSAPI_UTIL_H__
 
 #include <memory>
+#include <string>
 #include <stdbool.h>
 
 #include <glib-object.h>
@@ -65,6 +66,40 @@ public:
     }
 };
 
+template<typename T = GIBaseInfo>
+class GjsAutoInfo : public std::unique_ptr<T, decltype(&g_base_info_unref)> {
+public:
+    GjsAutoInfo(T *ptr = nullptr) : GjsAutoInfo::unique_ptr(ptr, g_base_info_unref) {}
+
+    operator T *() { return GjsAutoInfo::unique_ptr::get(); }
+
+    const char *name(void) const { return g_base_info_get_name(this->get()); }
+    GIInfoType type(void) const { return g_base_info_get_type(this->get()); }
+};
+
+/* For use of GjsAutoInfo<T> in GC hash maps */
+namespace JS {
+template<typename T>
+struct GCPolicy<GjsAutoInfo<T>> : public IgnoreGCPolicy<GjsAutoInfo<T>> {};
+}
+
+class GjsAutoParam
+    : public std::unique_ptr<GParamSpec, decltype(&g_param_spec_unref)> {
+    public:
+    GjsAutoParam(GParamSpec* ptr = nullptr)
+        : unique_ptr(ptr, g_param_spec_unref)
+    {
+    }
+
+    operator GParamSpec*() { return get(); }
+};
+
+/* For use of GjsAutoParam in GC hash maps */
+namespace JS {
+template<>
+struct GCPolicy<GjsAutoParam> : public IgnoreGCPolicy<GjsAutoParam> {};
+}  // namespace JS
+
 struct GjsJSFreeArgs {
     void operator() (char *str) {
         JS_free(nullptr, str);
@@ -219,8 +254,6 @@ bool        gjs_unichar_from_string          (JSContext       *context,
                                               JS::Value        string,
                                               gunichar        *result);
 
-const char* gjs_get_type_name                (JS::Value        value);
-
 /* Functions intended for more "internal" use */
 
 void gjs_maybe_gc (JSContext *context);
@@ -385,4 +418,10 @@ bool gjs_object_require_converted_property(JSContext       *cx,
                                                  value);
 }
 
+std::string gjs_debug_string(JSString *str);
+std::string gjs_debug_symbol(JS::Symbol * const sym);
+std::string gjs_debug_object(JSObject *obj);
+std::string gjs_debug_value(JS::Value v);
+std::string gjs_debug_id(jsid id);
+
 #endif  /* __GJS_JSAPI_UTIL_H__ */
